<?php

namespace Drupal\dcon_core\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\node\NodeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Conference Information Block.
 *
 * @Block(
 *   id = "conference_info_block",
 *   admin_label = @Translation("Conference Information"),
 *   category = @Translation("Conference")
 * )
 */
class ConferenceInfoBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new ConferenceInfoBlock instance.
   */
  public function __construct(
    array $configuration,
          $plugin_id,
          $plugin_definition,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $node = \Drupal::routeMatch()->getParameter('node');

    if (!$node || !$node instanceof NodeInterface || $node->bundle() !== 'conference') {
      return [];
    }

    if (!$node->hasField('field_header_section') || $node->get('field_header_section')->isEmpty()) {
      return [];
    }

    $header_paragraph = $node->get('field_header_section')->entity;

    if (!$header_paragraph) {
      return [];
    }

    $conference_dates = $header_paragraph->get('field_conference_date')->first()->getValue();

    if (empty($conference_dates['value']) || empty($conference_dates['end_value'])) {
      return [];
    }

    $date_formatter = \Drupal::service('date.formatter');

    $start_date = $date_formatter->format(
      strtotime($conference_dates['value']),
      'custom',
      'j F Y'
    );

    $end_date = $date_formatter->format(
      strtotime($conference_dates['end_value']),
      'custom',
      'j F Y'
    );

    $build = [
      '#theme' => 'conference_info',
      '#conference_details' => [
        'name' => $node->label(),
        'subtitle' => $header_paragraph->get('field_subtitle')->value ?? '',
        'location' => $header_paragraph->get('field_location')->value ?? '',
        'dates' => "{$start_date} - {$end_date}",
        'cta_link' => $header_paragraph->get('field_cta')->uri ?? '',
        'cta_text' => $header_paragraph->get('field_cta')->title ?? t('Register Now'), // Add this line
      ],
      '#cache' => [
        'max-age' => 900,
      ],
    ];

    return $build;
  }
}
